Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.busybox.net/busybox.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/test.c
diff options
context:
space:
mode:
Diffstat (limited to 'test.c')
-rw-r--r--test.c8
1 files changed, 7 insertions, 1 deletions
diff --git a/test.c b/test.c
index 85d06a83a..0ed777194 100644
--- a/test.c
+++ b/test.c
@@ -1,6 +1,6 @@
/* vi: set sw=4 ts=4: */
/*
* echo implementation for busybox
*
* Copyright (c) by a whole pile of folks:
*
@@ -185,6 +185,12 @@ test_main(int argc, char** argv)
fatalError("missing ]");
argv[argc] = NULL;
}
+ if (strcmp(argv[1], "--help") == 0) {
+ usage("test EXPRESSION\n"
+ "or [ EXPRESSION ]\n\n"
+ "Checks file types and compares values returning an exit\n"
+ "code determined by the value of EXPRESSION.\n");
+ }
/* Implement special cases from POSIX.2, section 4.62.4 */
switch (argc) {
@@ -1,6 +1,6 @@
/* vi: set sw=4 ts=4: */
/*
- * echo implementation for busybox
+ * test implementation for busybox
*
* Copyright (c) by a whole pile of folks: